@@ -2,6 +2,8 @@ import requests
 import pandas as pd
 import urllib.parse
 
+requests.packages.urllib3.disable_warnings()
+
 
 class Nts:
     """
@@ -9,7 +11,7 @@ class Nts:
     """
 
     def __init__(self, service_key=None):
-        self.serviceKey = service_key
+        self.service_key = service_key
         self.url_dict = {
             "진위확인": "https://api.odcloud.kr/api/nts-businessman/v1/validate",
             "상태조회": "https://api.odcloud.kr/api/nts-businessman/v1/status",
@@ -31,7 +33,7 @@ class Nts:
         """
         url = self.url_dict["진위확인"]
         params = {
-            "serviceKey": urllib.parse.unquote(self.serviceKey),
+            "serviceKey": urllib.parse.unquote(self.service_key),
         }
         if type(businesses) == pd.DataFrame:
             businesses = businesses.to_dict("records")
@@ -39,7 +41,8 @@ class Nts:
             "businesses": businesses,
         }
         try:
-            response = requests.post(url, params=params, json=json_data, verify=False)
+            response = requests.post(
+                url, params=params, json=json_data, verify=False)
             df = pd.json_normalize(response.json()['data'])
         except Exception as e:
             print("Error")
@@ -63,13 +66,14 @@ class Nts:
         """
         url = self.url_dict["상태조회"]
         params = {
-            "serviceKey": urllib.parse.unquote(self.serviceKey),
+            "serviceKey": urllib.parse.unquote(self.service_key),
         }
         data = {
             "b_no": b_no,
         }
         try:
-            response = requests.post(url, params=params, json=data, verify=False)
+            response = requests.post(
+                url, params=params, json=data, verify=False)
             df = pd.DataFrame(response.json()['data'])
         except Exception as e:
             print("Error")
